@@ -2,10 +2,9 @@ package Rose::HTML::Form::Field::RadioButton;
 
 use strict;
 
-use Rose::HTML::Form::Field::OnOff::Checkable;
-our @ISA = qw(Rose::HTML::Form::Field::OnOff::Checkable);
+use base 'Rose::HTML::Form::Field::OnOff::Checkable';
 
-our $VERSION = '0.551';
+our $VERSION = '0.606';
 
 __PACKAGE__->delete_valid_html_attrs(qw(ismap usemap alt src));
 __PACKAGE__->required_html_attr_value(type => 'radio');
@@ -177,4 +176,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
