@@ -4,8 +4,7 @@ use strict;
 
 use Carp();
 
-use Rose::HTML::Form::Field::Input;
-our @ISA = qw(Rose::HTML::Form::Field::Input);
+use base 'Rose::HTML::Form::Field::Input';
 
 use Rose::HTML::Object::MakeMethods::Localization
 (
@@ -21,7 +20,7 @@ __PACKAGE__->add_required_html_attrs(
   name  => '',
 });
 
-our $VERSION = '0.554';
+our $VERSION = '0.606';
 
 sub is_button { 1 }
 sub is_empty { 1 }
@@ -231,4 +230,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
